@@ -23,9 +23,9 @@ import time
 from typing import TYPE_CHECKING, Any
 
 import jmespath
-from botocore.exceptions import WaiterError
+from botocore.exceptions import NoCredentialsError, WaiterError
 
-from airflow.exceptions import AirflowException
+from airflow.providers.common.compat.sdk import AirflowException
 
 if TYPE_CHECKING:
     from botocore.waiter import Waiter
@@ -70,6 +70,10 @@ def wait(
             time.sleep(waiter_delay)
         try:
             waiter.wait(**args, WaiterConfig={"MaxAttempts": 1})
+
+        except NoCredentialsError as error:
+            log.info(str(error))
+
         except WaiterError as error:
             error_reason = str(error)
             last_response = error.last_response
@@ -131,6 +135,10 @@ async def async_wait(
             await asyncio.sleep(waiter_delay)
         try:
             await waiter.wait(**args, WaiterConfig={"MaxAttempts": 1})
+
+        except NoCredentialsError as error:
+            log.info(str(error))
+
         except WaiterError as error:
             error_reason = str(error)
             last_response = error.last_response
