@@ -16,13 +16,14 @@
 # under the License.
 from __future__ import annotations
 
+from functools import cache
 from pathlib import Path
 from unittest.mock import Mock, patch
 
 import boto3
 import pytest
 
-from airflow.providers.amazon.version_compat import AIRFLOW_V_3_0_PLUS
+from tests_common.test_utils.version_compat import AIRFLOW_V_3_0_PLUS
 
 if not AIRFLOW_V_3_0_PLUS:
     pytest.skip("AWS auth manager is only compatible with Airflow >= 3.0.0", allow_module_level=True)
@@ -100,11 +101,9 @@ def create_avp_policy_store(env_id):
 
 
 @pytest.fixture
+@cache
 def env_id():
-    global env_id_cache
-    if not env_id_cache:
-        env_id_cache = set_env_id("test_aws_auth_manager")
-    return env_id_cache
+    return set_env_id("test_aws_auth_manager")
 
 
 @pytest.fixture
@@ -113,11 +112,9 @@ def region_name():
 
 
 @pytest.fixture
+@cache
 def avp_policy_store_id(env_id):
-    global policy_store_id_cache
-    if not policy_store_id_cache:
-        policy_store_id_cache = create_avp_policy_store(env_id)
-    return policy_store_id_cache
+    return create_avp_policy_store(env_id)
 
 
 @pytest.fixture
